@@ -34,6 +34,36 @@ def bundle_resources(html_file, verbose):
     with open(html_file, 'r') as f:
         soup = BeautifulSoup(f.read(), 'html.parser')
     
+    # Add QuickDrop branding
+    branding_style = soup.new_tag('style')
+    branding_style.string = """
+        .quickdrop-brand {
+            position: fixed;
+            top: 12px;
+            right: 12px;
+            font-family: system-ui, -apple-system, sans-serif;
+            text-decoration: none;
+            padding: 4px 8px;
+            border-radius: 4px;
+            background: rgba(0, 0, 0, 0.05);
+            color: #666;
+            font-weight: 500;
+            font-size: 12px;
+            transition: opacity 0.2s ease;
+            z-index: 9999;
+        }
+        .quickdrop-brand:hover {
+            opacity: 0.8;
+        }
+    """
+    soup.head.append(branding_style)
+    
+    # Add branding link
+    branding_link = soup.new_tag('a', href='/', attrs={'class': 'quickdrop-brand'})
+    branding_link.string = 'hosted by QuickDrop'
+    if soup.body:
+        soup.body.append(branding_link)
+    
     # Handle CSS files
     for css_link in soup.find_all('link', rel='stylesheet'):
         href = css_link.get('href')
@@ -102,30 +132,37 @@ def replace_css_urls(css_content, css_dir, base_dir):
     # Find and replace all url() references
     return re.sub(r'url\([\'"]?([^\'"\)]+)[\'"]?\)', replace_url, css_content)
 
-@cli.command()
-@click.argument('file', type=click.Path(exists=True))
-@click.option('-v', '--verbose', is_flag=True, help='Show detailed output')
-def push(file, verbose):
+def pdfpush(file, api_url, headers, verbose):
+    """Push a PDF file to QuickDrop"""
+    try:
+        with open(file, 'rb') as f:
+            files = {'file': f}
+            response = requests.post(
+                f'{api_url}/pdfs/',
+                files=files,
+                headers=headers
+            )
+
+        if response.status_code == 201:
+            data = response.json()
+            click.echo('PDF upload successful!')
+            click.echo('Your PDF is available at: ')
+            click.echo(click.style(data['url'], fg='blue', underline=True), nl=False)
+            click.echo(' (CMD+Click to open)')
+            return True
+        else:
+            click.echo(f'Upload failed with status {response.status_code}')
+            click.echo(f'Error: {response.text}')
+            return False
+    except Exception as e:
+        click.echo(f'Error occurred: {str(e)}')
+        return False
+
+def htmlpush(file, api_url, headers, verbose):
     """Push an HTML file to QuickDrop"""
-    config = load_config()
-    if 'access_token' not in config:
-        click.echo('Please login first using: quickdrop login')
-        return
-
     try:
-        # Bundle the HTML with its resources
-        if verbose:
-            click.echo('Bundling resources...')
         html_content = bundle_resources(file, verbose)
-        
         filename = os.path.basename(file)
-        api_url = config.get('api_url', API_URL)
-        headers = {'Authorization': f'Bearer {config["access_token"]}'}
-        
-        if verbose:
-            click.echo(f'Making request to: {api_url}/deployments/')
-            click.echo(f'Headers: {headers}')
-            click.echo(f'Filename: {filename}')
         
         response = requests.post(
             f'{api_url}/deployments/',
@@ -136,20 +173,43 @@ def push(file, verbose):
             headers=headers
         )
         
-        if verbose:
-            click.echo(f'Response status: {response.status_code}')
-            
         if response.status_code == 201:
             data = response.json()
-            click.echo('Deployment successful!')
+            click.echo('HTML deployment successful!')
             click.echo('Your site is live at: ')
             click.echo(click.style(data['url'], fg='blue', underline=True), nl=False)
             click.echo(' (CMD+Click to open)')
+            return True
         else:
             click.echo(f'Deployment failed with status {response.status_code}')
             click.echo(f'Error: {response.text}')
+            return False
     except Exception as e:
         click.echo(f'Error occurred: {str(e)}')
+        return False
+
+@cli.command()
+@click.argument('file', type=click.Path(exists=True))
+@click.option('-v', '--verbose', is_flag=True, help='Show detailed output')
+def push(file, verbose):
+    """Push a file to QuickDrop"""
+    config = load_config()
+    if 'access_token' not in config:
+        click.echo('Please login first using: quickdrop login')
+        return
+
+    api_url = config.get('api_url', API_URL)
+    headers = {'Authorization': f'Bearer {config["access_token"]}'}
+    
+    file_ext = os.path.splitext(file)[1].lower()
+    
+    if file_ext == '.pdf':
+        return pdfpush(file, api_url, headers, verbose)
+    elif file_ext == '.html':
+        return htmlpush(file, api_url, headers, verbose)
+    else:
+        click.echo(f'Unsupported file type: {file_ext}. Only .pdf and .html files are supported.')
+        return False
 
 @cli.command()
 @click.option('--username', prompt=True)
@@ -280,6 +340,39 @@ def list():
     except Exception as e:
         click.echo(f'Error connecting to server: {str(e)}')
 
+@cli.command()
+def status():
+    """Show current connection status and server information"""
+    config = load_config()
+    api_url = config.get('api_url', API_URL)
+    
+    click.echo("\nQuickDrop Status")
+    click.echo("---------------")
+    click.echo(f"Server: {api_url}")
+    
+    if 'access_token' not in config:
+        click.echo(click.style("Status: Not logged in", fg='yellow'))
+        click.echo("\nTo login, use: quickdrop login")
+        return
+    
+    try:
+        # Try to make a request to verify the token
+        headers = {'Authorization': f'Bearer {config["access_token"]}'}
+        response = requests.get(f'{api_url}/deployments/', headers=headers)
+        
+        if response.status_code == 200:
+            user_data = response.json()
+            click.echo(click.style("Status: Connected", fg='green'))
+            if user_data:
+                click.echo(f"Active deployments: {len(user_data)}")
+        else:
+            click.echo(click.style("Status: Token expired or invalid", fg='red'))
+            click.echo("\nPlease login again using: quickdrop login")
+            
+    except Exception as e:
+        click.echo(click.style("Status: Connection error", fg='red'))
+        click.echo(f"Error: {str(e)}")
+
 @cli.command()
 def summary():
     """Show deployment analytics summary"""
@@ -315,5 +408,40 @@ def summary():
     except Exception as e:
         click.echo(f'Error connecting to server: {str(e)}')
 
+@cli.command()
+@click.argument('site_hash')
+@click.option('--force', is_flag=True, help='Skip confirmation prompt')
+def delete(site_hash, force):
+    """Permanently delete a deployment and all its versions"""
+    config = load_config()
+    if 'access_token' not in config:
+        click.echo('Please login first using: quickdrop login')
+        return
+
+    try:
+        if not force:
+            if not click.confirm(f'Are you sure you want to permanently delete site {site_hash}? This cannot be undone'):
+                click.echo('Operation cancelled.')
+                return
+
+        api_url = config.get('api_url', API_URL)
+        headers = {'Authorization': f'Bearer {config["access_token"]}'}
+        response = requests.delete(
+            f'{api_url}/deployments/{site_hash}/purge/',
+            headers=headers
+        )
+        
+        if response.status_code == 200:
+            click.echo(click.style('✔ ', fg='green') + 'Site deleted successfully')
+        elif response.status_code == 404:
+            click.echo(click.style('✘ ', fg='red') + 'Site not found')
+        else:
+            click.echo(click.style('✘ ', fg='red') + f'Failed to delete site: {response.text}')
+    except Exception as e:
+        click.echo(f'Error: {str(e)}')
+
+
+
+
 if __name__ == '__main__':
     cli()
\ No newline at end of file
